@@ -100,25 +100,25 @@ new IotToSqs(this, "test_iot_sqs", new IotToSqsProps.Builder()
 
 | **Name**     | **Type**        | **Description** |
 |:-------------|:----------------|-----------------|
-|iotTopicRuleProps|[`iot.CfnTopicRuleProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-iot.CfnTopicRuleProps.html)|User provided CfnTopicRuleProps to override the defaults|
-|existingQueueObj?|[`sqs.Queue`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-sqs.Queue.html)|Existing instance of SQS queue object, providing both this and `queueProps` will cause an error.|
-|queueProps?|[`sqs.QueueProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-sqs.QueueProps.html)|User provided props to override the default props for the SQS queue.|
-|deadLetterQueueProps?|[`sqs.QueueProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-sqs.QueueProps.html)|Optional user provided properties for the dead letter queue.|
+|iotTopicRuleProps|[`iot.CfnTopicRuleProps`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_iot.CfnTopicRuleProps.html)|User provided CfnTopicRuleProps to override the defaults|
+|existingQueueObj?|[`sqs.Queue`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_sqs.Queue.html)|Existing instance of SQS queue object, providing both this and `queueProps` will cause an error.|
+|queueProps?|[`sqs.QueueProps`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_sqs.QueueProps.html)|User provided props to override the default props for the SQS queue.|
+|deadLetterQueueProps?|[`sqs.QueueProps`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_sqs.QueueProps.html)|Optional user provided properties for the dead letter queue.|
 |deployDeadLetterQueue?|`boolean`|Whether to deploy a secondary queue to be used as a dead letter queue. Default `true`.|
 |maxReceiveCount?|`number`|The number of times a message can be unsuccessfully dequeued before being moved to the dead-letter queue. Required field if `deployDeadLetterQueue`=`true`.|
-|enableEncryptionWithCustomerManagedKey?|`boolean`|Use a KMS Key, either managed by this CDK app, or imported. If importing an encryption key, it must be specified in the `encryptionKey` property for this construct.|
-|encryptionKey?|[`kms.Key`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-kms.Key.html)|An optional, imported encryption key to encrypt the SQS queue.|
-|encryptionKeyProps?|[`kms.KeyProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-kms.KeyProps.html)|Optional user-provided props to override the default props for the encryption key.|
+|enableEncryptionWithCustomerManagedKey?|`boolean`|If no key is provided, this flag determines whether the queue is encrypted with a new CMK or an AWS managed key. This flag is ignored if any of the following are defined: queueProps.encryptionMasterKey, encryptionKey or encryptionKeyProps.|
+|encryptionKey?|[`kms.Key`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_kms.Key.html)|An optional, imported encryption key to encrypt the SQS Queue with.|
+|encryptionKeyProps?|[`kms.KeyProps`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_kms.Key.html#construct-props)|Optional user provided properties to override the default properties for the KMS encryption key used to encrypt the SQS queue with.|
 
 ## Pattern Properties
 
 | **Name**     | **Type**        | **Description** |
 |:-------------|:----------------|-----------------|
-|encryptionKey?|[`kms.Key`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-kms.Key.html)|Returns an instance of `kms.Key` used for the SQS queue.|
-|iotActionsRole|[`iam.Role`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-iam.Role.html)|Returns an instance of `iam.Role` created by the construct, which allows IoT to publish messages to the SQS Queue|
-|sqsQueue|[`sqs.Queue`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-sqs.Queue.html)|Returns an instance of `sqs.Queue` created by the construct|
-|deadLetterQueue?|[`sqs.Queue`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-sqs.Queue.html)|Returns an instance of the dead-letter SQS queue created by the pattern.|
-|iotTopicRule|[`iot.CfnTopicRule`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-iot.CfnTopicRule.html)|Returns an instance of `iot.CfnTopicRule` created by the construct|
+|encryptionKey?|[`kms.Key`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_kms.Key.html)|Returns an instance of `kms.Key` used for the SQS queue.|
+|iotActionsRole|[`iam.Role`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_iam.Role.html)|Returns an instance of `iam.Role` created by the construct, which allows IoT to publish messages to the SQS Queue|
+|sqsQueue|[`sqs.Queue`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_sqs.Queue.html)|Returns an instance of `sqs.Queue` created by the construct|
+|deadLetterQueue?|[`sqs.Queue`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_sqs.Queue.html)|Returns an instance of the dead-letter SQS queue created by the pattern.|
+|iotTopicRule|[`iot.CfnTopicRule`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_iot.CfnTopicRule.html)|Returns an instance of `iot.CfnTopicRule` created by the construct|
 
 ## Default settings
 
@@ -145,7 +145,7 @@ Out of the box implementation of the Construct without any override will set the
 ---
 
 
-© Copyright 2022 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+© Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 '''
 import abc
 import builtins
@@ -161,32 +161,32 @@ from typeguard import check_type
 
 from ._jsii import *
 
-import aws_cdk.aws_iam
-import aws_cdk.aws_iot
-import aws_cdk.aws_kms
-import aws_cdk.aws_sqs
-import constructs
+import aws_cdk.aws_iam as _aws_cdk_aws_iam_ceddda9d
+import aws_cdk.aws_iot as _aws_cdk_aws_iot_ceddda9d
+import aws_cdk.aws_kms as _aws_cdk_aws_kms_ceddda9d
+import aws_cdk.aws_sqs as _aws_cdk_aws_sqs_ceddda9d
+import constructs as _constructs_77d1e7e8
 
 
 class IotToSqs(
-    constructs.Construct,
+    _constructs_77d1e7e8.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-solutions-constructs/aws-iot-sqs.IotToSqs",
 ):
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         *,
-        iot_topic_rule_props: typing.Union[aws_cdk.aws_iot.CfnTopicRuleProps, typing.Dict[str, typing.Any]],
-        dead_letter_queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
+        iot_topic_rule_props: typing.Union[_aws_cdk_aws_iot_ceddda9d.CfnTopicRuleProps, typing.Dict[builtins.str, typing.Any]],
+        dead_letter_queue_props: typing.Optional[typing.Union[_aws_cdk_aws_sqs_ceddda9d.QueueProps, typing.Dict[builtins.str, typing.Any]]] = None,
         deploy_dead_letter_queue: typing.Optional[builtins.bool] = None,
         enable_encryption_with_customer_managed_key: typing.Optional[builtins.bool] = None,
-        encryption_key: typing.Optional[aws_cdk.aws_kms.Key] = None,
-        encryption_key_props: typing.Optional[typing.Union[aws_cdk.aws_kms.KeyProps, typing.Dict[str, typing.Any]]] = None,
-        existing_queue_obj: typing.Optional[aws_cdk.aws_sqs.Queue] = None,
+        encryption_key: typing.Optional[_aws_cdk_aws_kms_ceddda9d.Key] = None,
+        encryption_key_props: typing.Optional[typing.Union[_aws_cdk_aws_kms_ceddda9d.KeyProps, typing.Dict[builtins.str, typing.Any]]] = None,
+        existing_queue_obj: typing.Optional[_aws_cdk_aws_sqs_ceddda9d.Queue] = None,
         max_receive_count: typing.Optional[jsii.Number] = None,
-        queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
+        queue_props: typing.Optional[typing.Union[_aws_cdk_aws_sqs_ceddda9d.QueueProps, typing.Dict[builtins.str, typing.Any]]] = None,
     ) -> None:
         '''
         :param scope: - represents the scope for all the resources.
@@ -194,9 +194,9 @@ class IotToSqs(
         :param iot_topic_rule_props: User provided CfnTopicRuleProps to override the defaults. Default: - None
         :param dead_letter_queue_props: Optional user provided properties for the dead letter queue. Default: - Default props are used
         :param deploy_dead_letter_queue: Whether to deploy a secondary queue to be used as a dead letter queue. Default: - true.
-        :param enable_encryption_with_customer_managed_key: Use a KMS Key, either managed by this CDK app, or imported. If importing an encryption key, it must be specified in the encryptionKey property for this construct. Default: - true (encryption enabled, managed by this CDK app).
-        :param encryption_key: An optional, imported encryption key to encrypt the SQS queue, and SNS Topic. Default: - not specified.
-        :param encryption_key_props: Optional user-provided props to override the default props for the encryption key. Default: - Default props are used.
+        :param enable_encryption_with_customer_managed_key: If no key is provided, this flag determines whether the queue is encrypted with a new CMK or an AWS managed key. This flag is ignored if any of the following are defined: queueProps.encryptionMasterKey, encryptionKey or encryptionKeyProps. Default: - True if queueProps.encryptionMasterKey, encryptionKey, and encryptionKeyProps are all undefined.
+        :param encryption_key: An optional, imported encryption key to encrypt the SQS Queue with. Default: - None
+        :param encryption_key_props: Optional user provided properties to override the default properties for the KMS encryption key used to encrypt the SQS Queue with. Default: - None
         :param existing_queue_obj: Existing instance of SQS queue object, providing both this and queueProps will cause an error. Default: - None
         :param max_receive_count: The number of times a message can be unsuccessfully dequeued before being moved to the dead-letter queue. Default: - required field if deployDeadLetterQueue=true.
         :param queue_props: User provided props to override the default props for the SQS queue. Default: - Default props are used
@@ -205,7 +205,7 @@ class IotToSqs(
         :summary: Constructs a new instance of the IotToSqs class.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(IotToSqs.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__8b328331c182d26165eb18518ca63638bba4d15550c189523e542dfc167e0795)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = IotToSqsProps(
@@ -224,28 +224,30 @@ class IotToSqs(
 
     @builtins.property
     @jsii.member(jsii_name="iotActionsRole")
-    def iot_actions_role(self) -> aws_cdk.aws_iam.Role:
-        return typing.cast(aws_cdk.aws_iam.Role, jsii.get(self, "iotActionsRole"))
+    def iot_actions_role(self) -> _aws_cdk_aws_iam_ceddda9d.Role:
+        return typing.cast(_aws_cdk_aws_iam_ceddda9d.Role, jsii.get(self, "iotActionsRole"))
 
     @builtins.property
     @jsii.member(jsii_name="iotTopicRule")
-    def iot_topic_rule(self) -> aws_cdk.aws_iot.CfnTopicRule:
-        return typing.cast(aws_cdk.aws_iot.CfnTopicRule, jsii.get(self, "iotTopicRule"))
+    def iot_topic_rule(self) -> _aws_cdk_aws_iot_ceddda9d.CfnTopicRule:
+        return typing.cast(_aws_cdk_aws_iot_ceddda9d.CfnTopicRule, jsii.get(self, "iotTopicRule"))
 
     @builtins.property
     @jsii.member(jsii_name="sqsQueue")
-    def sqs_queue(self) -> aws_cdk.aws_sqs.Queue:
-        return typing.cast(aws_cdk.aws_sqs.Queue, jsii.get(self, "sqsQueue"))
+    def sqs_queue(self) -> _aws_cdk_aws_sqs_ceddda9d.Queue:
+        return typing.cast(_aws_cdk_aws_sqs_ceddda9d.Queue, jsii.get(self, "sqsQueue"))
 
     @builtins.property
     @jsii.member(jsii_name="deadLetterQueue")
-    def dead_letter_queue(self) -> typing.Optional[aws_cdk.aws_sqs.DeadLetterQueue]:
-        return typing.cast(typing.Optional[aws_cdk.aws_sqs.DeadLetterQueue], jsii.get(self, "deadLetterQueue"))
+    def dead_letter_queue(
+        self,
+    ) -> typing.Optional[_aws_cdk_aws_sqs_ceddda9d.DeadLetterQueue]:
+        return typing.cast(typing.Optional[_aws_cdk_aws_sqs_ceddda9d.DeadLetterQueue], jsii.get(self, "deadLetterQueue"))
 
     @builtins.property
     @jsii.member(jsii_name="encryptionKey")
-    def encryption_key(self) -> typing.Optional[aws_cdk.aws_kms.IKey]:
-        return typing.cast(typing.Optional[aws_cdk.aws_kms.IKey], jsii.get(self, "encryptionKey"))
+    def encryption_key(self) -> typing.Optional[_aws_cdk_aws_kms_ceddda9d.IKey]:
+        return typing.cast(typing.Optional[_aws_cdk_aws_kms_ceddda9d.IKey], jsii.get(self, "encryptionKey"))
 
 
 @jsii.data_type(
@@ -267,23 +269,23 @@ class IotToSqsProps:
     def __init__(
         self,
         *,
-        iot_topic_rule_props: typing.Union[aws_cdk.aws_iot.CfnTopicRuleProps, typing.Dict[str, typing.Any]],
-        dead_letter_queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
+        iot_topic_rule_props: typing.Union[_aws_cdk_aws_iot_ceddda9d.CfnTopicRuleProps, typing.Dict[builtins.str, typing.Any]],
+        dead_letter_queue_props: typing.Optional[typing.Union[_aws_cdk_aws_sqs_ceddda9d.QueueProps, typing.Dict[builtins.str, typing.Any]]] = None,
         deploy_dead_letter_queue: typing.Optional[builtins.bool] = None,
         enable_encryption_with_customer_managed_key: typing.Optional[builtins.bool] = None,
-        encryption_key: typing.Optional[aws_cdk.aws_kms.Key] = None,
-        encryption_key_props: typing.Optional[typing.Union[aws_cdk.aws_kms.KeyProps, typing.Dict[str, typing.Any]]] = None,
-        existing_queue_obj: typing.Optional[aws_cdk.aws_sqs.Queue] = None,
+        encryption_key: typing.Optional[_aws_cdk_aws_kms_ceddda9d.Key] = None,
+        encryption_key_props: typing.Optional[typing.Union[_aws_cdk_aws_kms_ceddda9d.KeyProps, typing.Dict[builtins.str, typing.Any]]] = None,
+        existing_queue_obj: typing.Optional[_aws_cdk_aws_sqs_ceddda9d.Queue] = None,
         max_receive_count: typing.Optional[jsii.Number] = None,
-        queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
+        queue_props: typing.Optional[typing.Union[_aws_cdk_aws_sqs_ceddda9d.QueueProps, typing.Dict[builtins.str, typing.Any]]] = None,
     ) -> None:
         '''
         :param iot_topic_rule_props: User provided CfnTopicRuleProps to override the defaults. Default: - None
         :param dead_letter_queue_props: Optional user provided properties for the dead letter queue. Default: - Default props are used
         :param deploy_dead_letter_queue: Whether to deploy a secondary queue to be used as a dead letter queue. Default: - true.
-        :param enable_encryption_with_customer_managed_key: Use a KMS Key, either managed by this CDK app, or imported. If importing an encryption key, it must be specified in the encryptionKey property for this construct. Default: - true (encryption enabled, managed by this CDK app).
-        :param encryption_key: An optional, imported encryption key to encrypt the SQS queue, and SNS Topic. Default: - not specified.
-        :param encryption_key_props: Optional user-provided props to override the default props for the encryption key. Default: - Default props are used.
+        :param enable_encryption_with_customer_managed_key: If no key is provided, this flag determines whether the queue is encrypted with a new CMK or an AWS managed key. This flag is ignored if any of the following are defined: queueProps.encryptionMasterKey, encryptionKey or encryptionKeyProps. Default: - True if queueProps.encryptionMasterKey, encryptionKey, and encryptionKeyProps are all undefined.
+        :param encryption_key: An optional, imported encryption key to encrypt the SQS Queue with. Default: - None
+        :param encryption_key_props: Optional user provided properties to override the default properties for the KMS encryption key used to encrypt the SQS Queue with. Default: - None
         :param existing_queue_obj: Existing instance of SQS queue object, providing both this and queueProps will cause an error. Default: - None
         :param max_receive_count: The number of times a message can be unsuccessfully dequeued before being moved to the dead-letter queue. Default: - required field if deployDeadLetterQueue=true.
         :param queue_props: User provided props to override the default props for the SQS queue. Default: - Default props are used
@@ -291,15 +293,15 @@ class IotToSqsProps:
         :summary: The properties for the IotToSqs class.
         '''
         if isinstance(iot_topic_rule_props, dict):
-            iot_topic_rule_props = aws_cdk.aws_iot.CfnTopicRuleProps(**iot_topic_rule_props)
+            iot_topic_rule_props = _aws_cdk_aws_iot_ceddda9d.CfnTopicRuleProps(**iot_topic_rule_props)
         if isinstance(dead_letter_queue_props, dict):
-            dead_letter_queue_props = aws_cdk.aws_sqs.QueueProps(**dead_letter_queue_props)
+            dead_letter_queue_props = _aws_cdk_aws_sqs_ceddda9d.QueueProps(**dead_letter_queue_props)
         if isinstance(encryption_key_props, dict):
-            encryption_key_props = aws_cdk.aws_kms.KeyProps(**encryption_key_props)
+            encryption_key_props = _aws_cdk_aws_kms_ceddda9d.KeyProps(**encryption_key_props)
         if isinstance(queue_props, dict):
-            queue_props = aws_cdk.aws_sqs.QueueProps(**queue_props)
+            queue_props = _aws_cdk_aws_sqs_ceddda9d.QueueProps(**queue_props)
         if __debug__:
-            type_hints = typing.get_type_hints(IotToSqsProps.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__425a0287466512764de98466f799742ad738b89a28a429f473ec05dc7b514f9b)
             check_type(argname="argument iot_topic_rule_props", value=iot_topic_rule_props, expected_type=type_hints["iot_topic_rule_props"])
             check_type(argname="argument dead_letter_queue_props", value=dead_letter_queue_props, expected_type=type_hints["dead_letter_queue_props"])
             check_type(argname="argument deploy_dead_letter_queue", value=deploy_dead_letter_queue, expected_type=type_hints["deploy_dead_letter_queue"])
@@ -309,7 +311,7 @@ class IotToSqsProps:
             check_type(argname="argument existing_queue_obj", value=existing_queue_obj, expected_type=type_hints["existing_queue_obj"])
             check_type(argname="argument max_receive_count", value=max_receive_count, expected_type=type_hints["max_receive_count"])
             check_type(argname="argument queue_props", value=queue_props, expected_type=type_hints["queue_props"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "iot_topic_rule_props": iot_topic_rule_props,
         }
         if dead_letter_queue_props is not None:
@@ -330,23 +332,25 @@ class IotToSqsProps:
             self._values["queue_props"] = queue_props
 
     @builtins.property
-    def iot_topic_rule_props(self) -> aws_cdk.aws_iot.CfnTopicRuleProps:
+    def iot_topic_rule_props(self) -> _aws_cdk_aws_iot_ceddda9d.CfnTopicRuleProps:
         '''User provided CfnTopicRuleProps to override the defaults.
 
         :default: - None
         '''
         result = self._values.get("iot_topic_rule_props")
         assert result is not None, "Required property 'iot_topic_rule_props' is missing"
-        return typing.cast(aws_cdk.aws_iot.CfnTopicRuleProps, result)
+        return typing.cast(_aws_cdk_aws_iot_ceddda9d.CfnTopicRuleProps, result)
 
     @builtins.property
-    def dead_letter_queue_props(self) -> typing.Optional[aws_cdk.aws_sqs.QueueProps]:
+    def dead_letter_queue_props(
+        self,
+    ) -> typing.Optional[_aws_cdk_aws_sqs_ceddda9d.QueueProps]:
         '''Optional user provided properties for the dead letter queue.
 
         :default: - Default props are used
         '''
         result = self._values.get("dead_letter_queue_props")
-        return typing.cast(typing.Optional[aws_cdk.aws_sqs.QueueProps], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_sqs_ceddda9d.QueueProps], result)
 
     @builtins.property
     def deploy_dead_letter_queue(self) -> typing.Optional[builtins.bool]:
@@ -361,42 +365,43 @@ class IotToSqsProps:
     def enable_encryption_with_customer_managed_key(
         self,
     ) -> typing.Optional[builtins.bool]:
-        '''Use a KMS Key, either managed by this CDK app, or imported.
+        '''If no key is provided, this flag determines whether the queue is encrypted with a new CMK or an AWS managed key.
 
-        If importing an encryption key, it must be specified in
-        the encryptionKey property for this construct.
+        This flag is ignored if any of the following are defined: queueProps.encryptionMasterKey, encryptionKey or encryptionKeyProps.
 
-        :default: - true (encryption enabled, managed by this CDK app).
+        :default: - True if queueProps.encryptionMasterKey, encryptionKey, and encryptionKeyProps are all undefined.
         '''
         result = self._values.get("enable_encryption_with_customer_managed_key")
         return typing.cast(typing.Optional[builtins.bool], result)
 
     @builtins.property
-    def encryption_key(self) -> typing.Optional[aws_cdk.aws_kms.Key]:
-        '''An optional, imported encryption key to encrypt the SQS queue, and SNS Topic.
+    def encryption_key(self) -> typing.Optional[_aws_cdk_aws_kms_ceddda9d.Key]:
+        '''An optional, imported encryption key to encrypt the SQS Queue with.
 
-        :default: - not specified.
+        :default: - None
         '''
         result = self._values.get("encryption_key")
-        return typing.cast(typing.Optional[aws_cdk.aws_kms.Key], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_kms_ceddda9d.Key], result)
 
     @builtins.property
-    def encryption_key_props(self) -> typing.Optional[aws_cdk.aws_kms.KeyProps]:
-        '''Optional user-provided props to override the default props for the encryption key.
+    def encryption_key_props(
+        self,
+    ) -> typing.Optional[_aws_cdk_aws_kms_ceddda9d.KeyProps]:
+        '''Optional user provided properties to override the default properties for the KMS encryption key used to encrypt the SQS Queue with.
 
-        :default: - Default props are used.
+        :default: - None
         '''
         result = self._values.get("encryption_key_props")
-        return typing.cast(typing.Optional[aws_cdk.aws_kms.KeyProps], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_kms_ceddda9d.KeyProps], result)
 
     @builtins.property
-    def existing_queue_obj(self) -> typing.Optional[aws_cdk.aws_sqs.Queue]:
+    def existing_queue_obj(self) -> typing.Optional[_aws_cdk_aws_sqs_ceddda9d.Queue]:
         '''Existing instance of SQS queue object, providing both this and queueProps will cause an error.
 
         :default: - None
         '''
         result = self._values.get("existing_queue_obj")
-        return typing.cast(typing.Optional[aws_cdk.aws_sqs.Queue], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_sqs_ceddda9d.Queue], result)
 
     @builtins.property
     def max_receive_count(self) -> typing.Optional[jsii.Number]:
@@ -408,13 +413,13 @@ class IotToSqsProps:
         return typing.cast(typing.Optional[jsii.Number], result)
 
     @builtins.property
-    def queue_props(self) -> typing.Optional[aws_cdk.aws_sqs.QueueProps]:
+    def queue_props(self) -> typing.Optional[_aws_cdk_aws_sqs_ceddda9d.QueueProps]:
         '''User provided props to override the default props for the SQS queue.
 
         :default: - Default props are used
         '''
         result = self._values.get("queue_props")
-        return typing.cast(typing.Optional[aws_cdk.aws_sqs.QueueProps], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_sqs_ceddda9d.QueueProps], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -434,3 +439,35 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__8b328331c182d26165eb18518ca63638bba4d15550c189523e542dfc167e0795(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    *,
+    iot_topic_rule_props: typing.Union[_aws_cdk_aws_iot_ceddda9d.CfnTopicRuleProps, typing.Dict[builtins.str, typing.Any]],
+    dead_letter_queue_props: typing.Optional[typing.Union[_aws_cdk_aws_sqs_ceddda9d.QueueProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    deploy_dead_letter_queue: typing.Optional[builtins.bool] = None,
+    enable_encryption_with_customer_managed_key: typing.Optional[builtins.bool] = None,
+    encryption_key: typing.Optional[_aws_cdk_aws_kms_ceddda9d.Key] = None,
+    encryption_key_props: typing.Optional[typing.Union[_aws_cdk_aws_kms_ceddda9d.KeyProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    existing_queue_obj: typing.Optional[_aws_cdk_aws_sqs_ceddda9d.Queue] = None,
+    max_receive_count: typing.Optional[jsii.Number] = None,
+    queue_props: typing.Optional[typing.Union[_aws_cdk_aws_sqs_ceddda9d.QueueProps, typing.Dict[builtins.str, typing.Any]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__425a0287466512764de98466f799742ad738b89a28a429f473ec05dc7b514f9b(
+    *,
+    iot_topic_rule_props: typing.Union[_aws_cdk_aws_iot_ceddda9d.CfnTopicRuleProps, typing.Dict[builtins.str, typing.Any]],
+    dead_letter_queue_props: typing.Optional[typing.Union[_aws_cdk_aws_sqs_ceddda9d.QueueProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    deploy_dead_letter_queue: typing.Optional[builtins.bool] = None,
+    enable_encryption_with_customer_managed_key: typing.Optional[builtins.bool] = None,
+    encryption_key: typing.Optional[_aws_cdk_aws_kms_ceddda9d.Key] = None,
+    encryption_key_props: typing.Optional[typing.Union[_aws_cdk_aws_kms_ceddda9d.KeyProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    existing_queue_obj: typing.Optional[_aws_cdk_aws_sqs_ceddda9d.Queue] = None,
+    max_receive_count: typing.Optional[jsii.Number] = None,
+    queue_props: typing.Optional[typing.Union[_aws_cdk_aws_sqs_ceddda9d.QueueProps, typing.Dict[builtins.str, typing.Any]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
